@@ -1,5 +1,4 @@
 import builtins
-import collections
 import itertools
 import re
 import sys
@@ -59,8 +58,8 @@ def get_full_import_name(import_from, name):
     return "{}.{}".format(module_name, partial_basename)
 
 
-def get_full_basename(node, basename):
-    """Resolve a partial base name to the full path.
+def resolve_qualname(node, basename):
+    """Resolve where a node is defined to get its fully qualified name.
 
     :param node: The node representing the base name.
     :type node: astroid.NodeNG
@@ -88,8 +87,10 @@ def get_full_basename(node, basename):
             full_basename = basename.replace(top_level_name, import_name, 1)
             break
         if isinstance(assignment, astroid.nodes.ClassDef):
-            full_basename = "{}.{}".format(assignment.root().name, assignment.name)
+            full_basename = assignment.qname()
             break
+        if isinstance(assignment, astroid.nodes.AssignName):
+            full_basename = "{}.{}".format(assignment.scope().qname(), assignment.name)
 
     if isinstance(node, astroid.nodes.Call):
         full_basename = re.sub(r"\(.*\)", "()", full_basename)
@@ -103,20 +104,17 @@ def get_full_basename(node, basename):
     return full_basename
 
 
-def get_full_basenames(bases, basenames):
-    """Resolve the base nodes and partial names of a class to full names.
+def get_full_basenames(node):
+    """Resolve the partial names of a class' bases to fully qualified names.
 
-    :param bases: The astroid node representing something that a class
-        inherits from.
-    :type bases: iterable(astroid.NodeNG)
-    :param basenames: The partial name of something that a class inherits from.
-    :type basenames: iterable(str)
+    :param node: The class definition node to resolve the bases of.
+    :type: astroid.ClassDef
 
     :returns: The full names.
     :rtype: iterable(str)
     """
-    for base, basename in zip(bases, basenames):
-        yield get_full_basename(base, basename)
+    for base in node.bases:
+        yield _resolve_annotation(base)
 
 
 def _get_const_values(node):
@@ -178,21 +176,13 @@ def get_assign_annotation(node):
     :returns: The type annotation as a string, or None if one does not exist.
     :rtype: str or None
     """
-    annotation = None
-
     annotation_node = None
     try:
         annotation_node = node.annotation
     except AttributeError:
         annotation_node = node.type_annotation
 
-    if annotation_node:
-        if isinstance(annotation_node, astroid.nodes.Const):
-            annotation = node.value
-        else:
-            annotation = annotation_node.as_string()
-
-    return annotation
+    return format_annotation(annotation_node, node)
 
 
 def is_decorated_with_property(node):
@@ -408,14 +398,20 @@ def _resolve_annotation(annotation):
     resolved = None
 
     if isinstance(annotation, astroid.Const):
-        resolved = get_full_basename(annotation, str(annotation.value))
+        resolved = resolve_qualname(annotation, str(annotation.value))
     elif isinstance(annotation, astroid.Name):
-        resolved = get_full_basename(annotation, annotation.name)
+        resolved = resolve_qualname(annotation, annotation.name)
     elif isinstance(annotation, astroid.Attribute):
-        resolved = get_full_basename(annotation, annotation.as_string())
+        resolved = resolve_qualname(annotation, annotation.as_string())
     elif isinstance(annotation, astroid.Subscript):
         value = _resolve_annotation(annotation.value)
-        slice_ = _resolve_annotation(annotation.slice)
+        slice_node = annotation.slice
+        if isinstance(slice_node, astroid.Index):
+            slice_node = slice_node.value
+        if isinstance(slice_node, astroid.Tuple):
+            slice_ = ", ".join(_resolve_annotation(elt) for elt in slice_node.elts)
+        else:
+            slice_ = _resolve_annotation(slice_node)
         resolved = f"{value}[{slice_}]"
     elif isinstance(annotation, astroid.Tuple):
         resolved = (
@@ -431,6 +427,12 @@ def _resolve_annotation(annotation):
     if resolved.startswith("typing."):
         return resolved[len("typing.") :]
 
+    # Sphinx is capable of linking anything in the same module
+    # without needing a fully qualified path.
+    module_prefix = annotation.root().name + "."
+    if resolved.startswith(module_prefix):
+        return resolved[len(module_prefix) :]
+
     return resolved
 
 
@@ -463,7 +465,7 @@ def _iter_args(args, annotations, defaults):
         yield (name, format_annotation(annotation, arg.parent), default)
 
 
-def _get_args_info(args_node):  # pylint: disable=too-many-branches,too-many-statements
+def get_args_info(args_node):  # pylint: disable=too-many-branches,too-many-statements
     result = []
     positional_only_defaults = []
     positional_or_keyword_defaults = args_node.defaults
@@ -562,31 +564,18 @@ def _get_args_info(args_node):  # pylint: disable=too-many-branches,too-many-sta
     return result
 
 
-def format_args(args_node):
-    result = []
+def get_return_annotation(node):
+    """Get the return annotation of a node.
+    :type node: astroid.nodes.FunctionDef
+    """
+    return_annotation = None
 
-    args_info = _get_args_info(args_node)
-    for prefix, name, annotation, default in args_info:
-        formatted = "{}{}{}{}".format(
-            prefix or "",
-            name or "",
-            ": {}".format(annotation) if annotation else "",
-            (" = {}" if annotation else "={}").format(default) if default else "",
-        )
-        result.append(formatted)
+    if node.returns:
+        return_annotation = format_annotation(node.returns, node)
+    elif node.type_comment_returns:
+        return_annotation = format_annotation(node.type_comment_returns, node)
 
-    return ", ".join(result)
-
-
-def get_annotations_dict(args_node):
-    result = collections.OrderedDict()
-
-    args_info = _get_args_info(args_node)
-    for _, name, annotation, __ in args_info:
-        if name and annotation:
-            result[name] = annotation
-
-    return result
+    return return_annotation
 
 
 def get_func_docstring(node):
